# Generated by roxygen2: do not edit by hand

S3method(cookies,rvest_session)
S3method(format,rvest_field)
S3method(headers,rvest_session)
S3method(html_element,LiveHTML)
S3method(html_element,default)
S3method(html_element,rvest_session)
S3method(html_elements,LiveHTML)
S3method(html_elements,default)
S3method(html_elements,rvest_session)
S3method(html_form,rvest_session)
S3method(html_form,xml_document)
S3method(html_form,xml_node)
S3method(html_form,xml_nodeset)
S3method(html_table,LiveHTML)
S3method(html_table,rvest_session)
S3method(html_table,xml_document)
S3method(html_table,xml_node)
S3method(html_table,xml_nodeset)
S3method(html_text2,xml_document)
S3method(html_text2,xml_missing)
S3method(html_text2,xml_node)
S3method(html_text2,xml_nodeset)
S3method(print,rvest_field)
S3method(print,rvest_form)
S3method(print,rvest_session)
S3method(read_html,rvest_session)
S3method(status_code,rvest_session)
export("%>%")
export(LiveHTML)
export(back)
export(follow_link)
export(forward)
export(google_form)
export(guess_encoding)
export(html_attr)
export(html_attrs)
export(html_children)
export(html_element)
export(html_elements)
export(html_encoding_guess)
export(html_form)
export(html_form_set)
export(html_form_submit)
export(html_name)
export(html_node)
export(html_nodes)
export(html_session)
export(html_table)
export(html_text)
export(html_text2)
export(is.session)
export(jump_to)
export(minimal_html)
export(read_html)
export(read_html_live)
export(repair_encoding)
export(session)
export(session_back)
export(session_follow_link)
export(session_forward)
export(session_history)
export(session_jump_to)
export(session_submit)
export(set_values)
export(submit_form)
export(url_absolute)
export(xml_node)
export(xml_nodes)
export(xml_tag)
import(rlang)
importFrom(glue,glue)
importFrom(httr,cookies)
importFrom(httr,headers)
importFrom(httr,status_code)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(xml2,read_html)
importFrom(xml2,url_absolute)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_attrs)
importFrom(xml2,xml_children)
importFrom(xml2,xml_name)
importFrom(xml2,xml_text)
